@@ -2,21 +2,33 @@ from typing import Optional, Union, Dict, List, Tuple
 import os
 
 from quickstats import PathManager
+from quickstats.utils.common_utils import combine_dict
 
 class AnalysisPathManager(PathManager):
     
-    DEFAULT_DIRECTORIES = {}
+    DEFAULT_DIRECTORIES = {
+        "yield"        : "yields",
+        "minitree"     : "minitrees",
+        "summary"      : "summary",
+        "plot"         : "plots",
+        "xml"          : "xmls",
+        "workspace"    : "xmls/workspace",
+        "xml_config"   : "xmls/config",
+        "xml_data"     : "xmls/config/data",
+        "xml_model"    : "xmls/config/models",
+        "xml_category" : "xmls/config/categories",
+        "limit"        : "limits",
+        "likelihood"   : "likelihood"
+    }
+    
     DEFAULT_FILES       = {}
     
     def __init__(self, study_name:str="", base_path:Optional[str]=None,
                  directories:Optional[Dict[str, str]]=None,
                  files:Optional[Dict[str, Union[str, Tuple[Optional[str], str]]]]=None):
         
-        if directories is None:
-            directories = self.DEFAULT_DIRECTORIES
-            
-        if files is None:
-            files = self.DEFAULT_FILES
+        directories = combine_dict(self.DEFAULT_DIRECTORIES, directories)
+        files       = combine_dict(self.DEFAULT_FILES, files)
             
         super().__init__(base_path=base_path, directories=directories, files=files)
         
