@@ -10,8 +10,8 @@ import numpy as np
 
 import ROOT
 
-from quickstats import semistaticmethod
-from quickstats.components import AbstractObject, ExtendedModel
+from quickstats import semistaticmethod, AbstractObject
+from quickstats.components import ExtendedModel
 from quickstats.utils.io import Verbosity
 from quickstats.utils.xml_tools import TXMLTree
 from quickstats.utils.common_utils import remove_list_duplicates, format_delimiter_enclosed_text
