@@ -18,7 +18,7 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
                  file_expr:Optional[str]=None, param_expr:Optional[str]=None,
                  filter_expr:Optional[str]=None, exclude_expr:Optional[str]=None,
                  outdir:str="output", outname:str="limits.json",
-                 save_summary:bool=True, cache:bool=True,
+                 save_summary:bool=False, cache:bool=True,
                  save_log:bool=True, parallel:int=-1,
                  verbosity:Optional[Union[int, str]]="INFO"):
         
@@ -56,14 +56,16 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
     
     @semistaticmethod
     def _run_instance(self, filename:str, config:Dict[str, Any],
+                      parameters:Dict[str, Any],
                       outname:Optional[str]=None,
-                      save_summary:bool=True, **kwargs):
+                      save_summary:bool=True,
+                      **kwargs):
         try:
             config['filename'] = filename
             asymptotic_cls = AsymptoticCLs(**config)
             asymptotic_cls.evaluate_limits()
             if outname is not None:
-                asymptotic_cls.save(outname, summary=save_summary)
+                asymptotic_cls.save(outname, parameters=parameters, summary=save_summary)
             return asymptotic_cls.limits
         except Exception as e:
             sys.stdout.write(f"{e}\n")
