@@ -3,4 +3,6 @@ from .methods import *
 from .abstract_object import AbstractObject
 from .enums import GeneralEnum, DescriptiveEnum
 from .virtual_trees import TVirtualNode, TVirtualTree
-from .path_manager import DynamicFilePath, PathManager
\ No newline at end of file
+from .path_manager import DynamicFilePath, PathManager
+from .configs import ConfigComponent, ConfigParser
+from .configurable_object import ConfigurableObject
\ No newline at end of file
